Learn R Programming

bivgeom (version 1.0)

FyxbivgeomRoy: Conditional distribution

Description

Conditional distribution function of \(Y\) given \(X=x\)

Usage

FyxbivgeomRoy(y, theta1, theta2, theta3, x)

Arguments

y

vector of observations from \(Y\)

theta1

paramater \(\theta_1\)

theta2

paramater \(\theta_2\)

theta3

paramater \(\theta_3\)

x

value of the conditioning variable \(X\)

Value

The value of the conditional cumulative distribution function \(F_{Y|x}\) in \(y\). Used in rbivgeomRoy for conditional sampling

References

Roy, D. (1993) Reliability measures in the discrete bivariate set-up and related characterization results for a bivariate geometric distribution, Journal of Multivariate Analysis 46(2), 362-373.

See Also

EyxbivgeomRoy, rbivgeomRoy

Examples

Run this code
# NOT RUN {
theta1 <- 0.5
theta2 <- 0.7
theta3 <- 0.9
# probability that Y<=3 given that X=2:
FyxbivgeomRoy(3, theta1, theta2, theta3, 2)
# the unconditional probability would be
pgeom(3, 1-theta2) # i.e. a geometric distribution with parameter 1-theta2
# }

Run the code above in your browser using DataLab