Learn R Programming

bivgeom (version 1.0)

corbivgeomRoy: Linear correlation

Description

Linear correlation for Roy's bivariate geometric model

Usage

corbivgeomRoy(theta1, theta2, theta3)

Arguments

theta1

paramater \(\theta_1\)

theta2

paramater \(\theta_2\)

theta3

paramater \(\theta_3\)

Value

the value of Pearson's linear correlation - see Barbiero (2018). The linear correlation for Roy's bivariate geometric distribution is negative (or null, for \(\theta_3=1\)) for any feasible choice of its parameters

References

Roy, D. (1993) Reliability measures in the discrete bivariate set-up and related characterization results for a bivariate geometric distribution, Journal of Multivariate Analysis 46(2), 362-373.

Barbiero, A. (2018) Properties and estimation of a bivariate geometric model with locally constant failure rates, submitted

See Also

dbivgeomRoy

Examples

Run this code
# NOT RUN {
corbivgeomRoy(0.3,0.7,0.5)
# }

Run the code above in your browser using DataLab