Stress-strength reliability parameter \(R\) for Roy's bivariate geometric model
Usage
RelbivgeomRoy(theta1, theta2, theta3)
Arguments
theta1
paramater \(\theta_1\)
theta2
paramater \(\theta_2\)
theta3
paramater \(\theta_3\)
Value
The probability \(R:=P(X\leq Y)\) for Roy's bivariate geometric model - see Barbiero (2018) for its computation
References
Barbiero, A. (2018) Properties and estimation of a bivariate geometric model with locally constant failure rates, submitted
Roy, D. (1993) Reliability measures in the discrete bivariate set-up and related characterization results for a bivariate geometric distribution, Journal of Multivariate Analysis 46(2), 362-373.